==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/news/classes/NewsDialogBase.php <==
<?php
$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] ?: array()) + array("_aed8da0f190912" . "14b78f803510485" . "17c" => base64_decode("c3Ry" . "bGVu"));




abstract class NewsDialogBase extends ErrorHandler
{
    
    
    
    
    
    
    protected $news_item;
    
    
    
    
    
    
    protected $is_admin = false;
    protected $lang_dialog;
    
    
    
    
    
    
    
    public function __construct(NewsItemBase $_60378eae7533ef2a18e2cf710db06291, $admin_mode = false)
    {
        $this->news_item = $_60378eae7533ef2a18e2cf710db06291;
        $this->is_admin = $admin_mode;
        $this->lang_dialog = new LanguageDialog($_60378eae7533ef2a18e2cf710db06291);
    }
    
    
    
    
    
    
    public function IsAdmin()
    {
        return $this->is_admin;
    }
    
    
    
    
    
    
    
    
    
    
    protected static function ParseDate($_b1587f9c43f1b559c8731e6cf60b2173, $_c8b38c7133c2e8460c1cca42230ac6c2 = '00:00')
    {
        if ($GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_aed8da0f19091214b78f80" . "351048517c"]($_b1587f9c43f1b559c8731e6cf60b2173) == 0) {
            return null;
        }
        $_67a0d624aebcceb0abd5ce56a53ff06f = Date::CreateFrom($_b1587f9c43f1b559c8731e6cf60b2173, $_c8b38c7133c2e8460c1cca42230ac6c2);
        if (!$_67a0d624aebcceb0abd5ce56a53ff06f) {
            return null;
        }
        return $_67a0d624aebcceb0abd5ce56a53ff06f->getDate(DATE_FORMAT_TIMESTAMP);
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/news/classes/NewsDialogBase.php <==
<?php
$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"] ?: array()) + array("_aed8da0f19091214b78f80351048" . "517c" => base64_decode("c3Ry" . "bGVu"));




abstract class NewsDialogBase extends ErrorHandler
{
    
    
    
    
    
    
    protected $news_item;
    
    
    
    
    
    
    protected $is_admin = false;
    protected $lang_dialog;
    
    
    
    
    
    
    
    public function __construct(NewsItemBase $_60378eae7533ef2a18e2cf710db06291, $admin_mode = false)
    {
        $this->news_item = $_60378eae7533ef2a18e2cf710db06291;
        $this->is_admin = $admin_mode;
        $this->lang_dialog = new LanguageDialog($_60378eae7533ef2a18e2cf710db06291);
    }
    
    
    
    
    
    
    public function IsAdmin()
    {
        return $this->is_admin;
    }
    
    
    
    
    
    
    
    
    
    
    protected static function ParseDate($_b1587f9c43f1b559c8731e6cf60b2173, $_c8b38c7133c2e8460c1cca42230ac6c2 = '00:00')
    {
        if ($GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_aed8da0f19091214b78" . "f80351048517c"]($_b1587f9c43f1b559c8731e6cf60b2173) == 0) {
            return null;
        }
        $_67a0d624aebcceb0abd5ce56a53ff06f = Date::CreateFrom($_b1587f9c43f1b559c8731e6cf60b2173, $_c8b38c7133c2e8460c1cca42230ac6c2);
        if (!$_67a0d624aebcceb0abd5ce56a53ff06f) {
            return null;
        }
        return $_67a0d624aebcceb0abd5ce56a53ff06f->getDate(DATE_FORMAT_TIMESTAMP);
    }
}
